Welcome to ClientVPS Mirrors

Help for package hflights
Type: Package
Title: Flights that departed Houston in 2011
Version: 0.1
Author: Hadley Wickham <h.wickham@gmail.com>
Maintainer: Hadley Wickham <h.wickham@gmail.com>
License: CC0
Description: A data only package containing commercial domestic flights that departed Houston (IAH and HOU) in 2011.
Depends: R (≥ 2.10)
LazyData: true
Packaged: 2013-12-06 21:42:40 UTC; hadley
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2013-12-07 01:00:06

Houston flights data

Description

This dataset contains all flights departing from Houston airports IAH (George Bush Intercontinental) and HOU (Houston Hobby). The data comes from the Research and Innovation Technology Administration at the Bureau of Transporation statistics: http://www.transtats.bts.gov/DatabaseInfo.asp?DB_ID=120&Link=0

Usage

hflights

Format

A data frame with 227,496 rows and 21 columns.

Details

src_hflights caches a SQLite version of the data in a standard location for use in examples.

Variables

Examples

head(hflights)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.